@@ -10,7 +10,7 @@ from semver.version import Version
 
 from . import logger
 from .client import client_factory
-from .exceptions import Ops2debError, UpdaterError
+from .exceptions import Ops2debError, Ops2debUpdaterError
 from .fetcher import download_file_to_cache
 from .parser import Blueprint, load, validate
 
@@ -33,7 +33,7 @@ class NewRelease:
 
 def _error(msg: str) -> None:
     logger.error(msg)
-    raise UpdaterError(msg)
+    raise Ops2debUpdaterError(msg)
 
 
 async def _bump_and_poll(
@@ -104,8 +104,7 @@ async def _update_blueprint_dict(blueprint_dict: Dict[str, Any]) -> Optional[New
 
     blueprint_dict["version"] = release.new_version
     blueprint_dict["fetch"]["sha256"] = release.sha256
-    if "revision" in blueprint_dict.keys():
-        blueprint_dict["revision"] = 1
+    blueprint_dict.pop("revision", None)
     return release
 
 
@@ -120,9 +119,16 @@ def update(
 
     logger.title("Looking for new releases...")
 
+    # configuration file can be a list of blueprints or a single blueprint
+    blueprints_dict = (
+        configuration_dict
+        if isinstance(configuration_dict, list)
+        else [configuration_dict]
+    )
+
     async def run_tasks() -> Any:
         return await asyncio.gather(
-            *[_update_blueprint_dict(b) for b in configuration_dict],
+            *[_update_blueprint_dict(b) for b in blueprints_dict],
             return_exceptions=True,
         )
 
@@ -150,4 +156,4 @@ def update(
         logger.info("Did not found any updates")
 
     if errors:
-        raise UpdaterError(f"{len(errors)} failures occurred")
+        raise Ops2debUpdaterError(f"{len(errors)} failures occurred")
